.. module:: aioredis.abc

:mod:`aioredis.abc` --- Interfaces Reference
============================================

This module defines several abstract classes that must be used
when implementing custom connection managers or other features.


.. autoclass:: AbcConnection
   :show-inheritance:
   :members:

.. autoclass:: AbcPool
   :show-inheritance:
   :members:

.. autoclass:: AbcChannel
   :show-inheritance:
   :members:
